@@ -95,6 +95,51 @@ class GreekingTemplateTagTests(TestCase):
             "{% load greeking_tags %}{% fillmurray 200 200 blue %}"
         )
 
+    def testPlaceholdIt(self):
+        """
+        Tests the tag for pulling placehold.it images.
+        """
+        t1 = "{% load greeking_tags %}{% placeholdit 250 250 %}"
+        ctx, out = self.render(t1)
+        self.assertEqual(
+            out, '<img src="http://placehold.it/250x250/cccccc/969696/"/>'
+        )
+        t2 = "{% load greeking_tags %}{% placeholdit 100 200 %}"
+        ctx, out = self.render(t2)
+        self.assertEqual(
+            out, '<img src="http://placehold.it/100x200/cccccc/969696/"/>'
+        )
+        t3 = "{% load greeking_tags %}{% placeholdit 100 200 \
+background_color='fff' text_color='000' %}"
+        ctx, out = self.render(t3)
+        self.assertEqual(
+            out, '<img src="http://placehold.it/100x200/fff/000/"/>'
+        )
+        t4 = "{% load greeking_tags %}{% placeholdit 100 200 \
+text='Hello LA' %}"
+        ctx, out = self.render(t4)
+        self.assertEqual(
+            out, '<img src="http://placehold.it/100x200/cccccc/969696/\
+&text=Hello+LA"/>'
+        )
+        t5 = "{% load greeking_tags %}{% placeholdit 100 200 'fff' \
+'000' 'Hello LA' %}"
+        ctx, out = self.render(t5)
+        self.assertEqual(
+            out,
+            '<img src="http://placehold.it/100x200/fff/000/&text=Hello+LA"/>'
+        )
+        self.assertRaises(
+            TemplateSyntaxError,
+            self.render,
+            "{% load greeking_tags %}{% placeholdit foobar %}"
+        )
+        self.assertRaises(
+            TemplateSyntaxError,
+            self.render,
+            "{% load greeking_tags %}{% placeholdit 200 200 b a b c d e%}"
+        )
+
     def testPlaceKittens(self):
         """
         Tests the tag for pulling placekitten images.
